@@ -28,22 +28,44 @@
 
 G_BEGIN_DECLS
 
+#include <libgd/gd-types-catalog.h>
+
 #ifdef LIBGD_GTK_HACKS
 # include <libgd/gd-icon-utils.h>
 # include <libgd/gd-entry-focus-hack.h>
 #endif
 
+#ifdef LIBGD__VIEW_COMMON
+# include <libgd/gd-main-view-generic.h>
+# include <libgd/gd-styled-text-renderer.h>
+# include <libgd/gd-two-lines-renderer.h>
+#endif
+
 #ifdef LIBGD_MAIN_ICON_VIEW
 # include <libgd/gd-main-icon-view.h>
-# include <libgd/gd-main-view-generic.h>
 # include <libgd/gd-toggle-pixbuf-renderer.h>
-# include <libgd/gd-two-lines-renderer.h>
+#endif
+
+#ifdef LIBGD_MAIN_LIST_VIEW
+# include <libgd/gd-main-list-view.h>
+#endif
+
+#ifdef LIBGD_MAIN_VIEW
+# include <libgd/gd-main-view.h>
 #endif
 
 #ifdef LIBGD_MAIN_TOOLBAR
 # include <libgd/gd-main-toolbar.h>
 #endif
 
+#ifdef LIBGD_HEADER_BAR
+# include <libgd/gd-header-bar.h>
+#endif
+
+#ifdef LIBGD__HEADER_BUTTON
+# include <libgd/gd-header-button.h>
+#endif
+
 #ifdef LIBGD_MARGIN_CONTAINER
 # include <libgd/gd-margin-container.h>
 #endif
@@ -52,6 +74,19 @@ G_BEGIN_DECLS
 # include <libgd/gd-tagged-entry.h>
 #endif
 
+#ifdef LIBGD_NOTIFICATION
+# include <libgd/gd-notification.h>
+#endif
+
+#ifdef LIBGD_REVEALER
+# include <libgd/gd-revealer.h>
+#endif
+
+#ifdef LIBGD_STACK
+# include <libgd/gd-stack.h>
+# include <libgd/gd-stack-switcher.h>
+#endif
+
 G_END_DECLS
 
 #endif /* __GD_H__ */
