@@ -370,6 +370,13 @@ const DocCommon = new Lang.Class({
         log('Error: DocCommon implementations must override canTrash');
     },
 
+    canPrint: function(docModel) {
+        if (!docModel)
+            return false;
+
+        return EvView.PrintOperation.exists_for_document(docModel.get_document());
+    },
+
     trash: function() {
         if (!this.canTrash())
             return;
@@ -609,6 +616,9 @@ const DocCommon = new Lang.Class({
                     return;
                 }
 
+                if (!this.canPrint(docModel))
+                    return;
+
                 let printOp = EvView.PrintOperation.new(docModel.get_document());
 
                 printOp.connect('begin-print', Lang.bind(this,
@@ -672,13 +682,25 @@ const LocalDocument = new Lang.Class({
         this.sourceName = _("Local");
 
         if (this.mimeType) {
+            let defaultApp = Gio.app_info_get_default_for_type(this.mimeType, true);
+            let recommendedApp = null;
+
             let apps = Gio.app_info_get_recommended_for_type (this.mimeType);
             for (let i = 0; i < apps.length; i++) {
                 if (apps[i].supports_uris ()) {
-                    this.defaultApp = apps[i];
-                    break;
+                    if (defaultApp && apps[i].equal (defaultApp)) {
+                        // Found the recommended app that's also the default
+                        recommendedApp = apps[i];
+                        break;
+                    }
+                    // Set the first recommendedApp as the default if
+                    // they don't match
+                    if (!recommendedApp)
+                        recommendedApp = apps[i];
                 }
             }
+
+            this.defaultApp = recommendedApp;
         }
 
         if (this.defaultApp)
